@@ -283,7 +283,7 @@ as_yearweek <- function(x, ...) {
 #' @rdname as_yearweek
 #' @export
 as_yearweek.default <- function(x, ...) {
-    stopf("Not implemented for class [%s].", paste(class(x), collapse = ", "))
+    stopf("Not implemented for class [%s].", toString(class(x)))
 }
 
 # -------------------------------------------------------------------------
